pub fn compare_backends(op: &dyn OpUnderTest, seed: u64) -> NmseReportExpand description
Run op on every backend the current build supports and assemble
the comparison report.
pub fn compare_backends(op: &dyn OpUnderTest, seed: u64) -> NmseReportRun op on every backend the current build supports and assemble
the comparison report.