GemmOp

Struct GemmOp 

pub struct GemmOp {
    pub m: usize,
    pub n: usize,
    pub k: usize,
}
C[m, n] = A[m, k] · B[n, k]^T (row-major, B already transposed to head-major). Matches the Backend::gemm signature used by Linear.

Fields

m: usizen: usizek: usize

Implementations

Source

impl GemmOp

pub fn expected_output_len(&self) -> Result<usize, String>

Validate buffer sizes and the signed indices used by Metal/cuBLAS. These are arithmetic limits, not a guarantee of available device memory.

Examples found in repository?
examples/backend_numerics/config.rs (line 92)
77    fn expected_output_len(&self) -> Result<usize, String> {
78        match *self {
79            Self::MetalContext {
80                tokens,
81                intermediate,
82                k,
83            } => MetalContextOp {
84                tokens,
85                intermediate,
86                k,
87            }
88            .expected_output_len(),
89            Self::RmsNorm { tokens, dim, eps } => {
90                RmsNormOp { tokens, dim, eps }.expected_output_len()
91            }
92            Self::Gemm { m, n, k } => GemmOp { m, n, k }.expected_output_len(),
93            Self::SiluMul {
94                tokens,
95                intermediate,
96            } => SiluMulOp {
97                tokens,
98                intermediate,
99            }
100            .expected_output_len(),
101        }
102    }