pub struct ConfigurableModelExecutor { /* private fields */ }Expand description
Model executor that produces a configurable sequence of tokens.
Implementations
Sourceimpl ConfigurableModelExecutor
impl ConfigurableModelExecutor
Sourcepub fn with_token_sequence(vocab_size: usize, tokens: Vec<u32>) -> Self
pub fn with_token_sequence(vocab_size: usize, tokens: Vec<u32>) -> Self
Create executor that cycles through the given token sequence.
Sourcepub fn with_eos_after(vocab_size: usize, n: usize, eos_token: u32) -> Self
pub fn with_eos_after(vocab_size: usize, n: usize, eos_token: u32) -> Self
Create executor that emits EOS after n decode steps.